#
# spec file for package python-cached-property
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-cached-property
Version:        1.5.2
Release:        4.7
Summary:        A decorator for caching properties in classes
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/pydanny/cached-property
Source:         https://files.pythonhosted.org/packages/source/c/cached-property/cached-property-%{version}.tar.gz
# PATCH-FIX-UPSTREAM skip test that rely on wrong freezegun behaviour
# https://github.com/pydanny/cached-property/pull/125
Patch0:         freezegun-skip.patch
# PATCH-FIX-UPSTREAM Don't use asyncio.coroutine if it's not available -- https://github.com/pydanny/cached-property/pull/267
Patch1:         python311.patch
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A decorator for caching properties in classes. It makes caching of time or
computational expensive properties quick and easy and it works in Python 2
and 3.

%prep
%autosetup -p1 -n cached-property-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst HISTORY.rst
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Feb 10 2023 Matej Cepl <mcepl@suse.com>
- Refresh patches and remove weird replacement of conftest.py
  command in %%%%prep.
* Tue Jan 31 2023 Dirk Müller <dmueller@suse.com>
- add python311.patch to fix tests with 3.11
* Sat Dec 19 2020 Dirk Müller <dmueller@suse.com>
- update to 1.5.2:
  * Add formal support for Python 3.8
  * Remove formal support for Python 3.4
  * Switch from Travis to GitHub actions
  * Made tests pass flake8 for Python 2.7
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Replace nose with pytest
- Add missing Group
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2 available
* Mon Feb 25 2019 John Vandenberg <jayvdb@gmail.com>
- Add HISTORY.rst to %%doc
- Update to v1.5.1
  * Added formal support for Python 3.7
  * Removed formal support for Python 3.3
- from 1.4.3
  * Catch SyntaxError from asyncio import on older versions of Python
- from 1.4.2
  * Really fixed tests
- from 1.4.1
  * Added conftest.py to manifest so tests work properly off the tarball
  * Ensured new asyncio tests didn't break Python 2.7 builds on Debian
  * Code formatting via black
- from 1.4.0
  * Added asyncio support
  * Remove Python 2.6 support, whose end of life was 5 years ago
- from 1.3.1
  * Validate for Python 3.6
* Fri Feb  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with new freezegun (by skipping test):
  * freezegun-skip.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Aug 19 2017 sebix+novell.com@sebix.at
- singlespec version
* Thu Mar 17 2016 jmassaguerpla@suse.com
- initial commit with version 1.3.0
